find_closest_year: Find closest year

View source: R/helpers.R

find_closest_yearR Documentation

Find closest year

Description

This function takes a date as input and returns the closest year.

Usage

find_closest_year(date)

Arguments

date

[character(1)]
The date in format "YYYY-MM-DD".

Value

An integer, the closest year to the input date.


fHMM documentation built on May 5, 2026, 5:07 p.m.