View source: R/get_initial_values.R
| get_initial_values | R Documentation |
This helper function generates a set of initial values for the numerical optimization of the model likelihood function.
get_initial_values(
data,
ncluster = 1,
seed = NULL,
verbose = TRUE,
initial_estimate = NULL
)
data |
[ |
ncluster |
[ |
seed |
[ |
verbose |
[ |
initial_estimate |
[
|
A list, where each element is an object of class parUncon.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.